/* Written by Morgoth DBMA, morgothdbma@o2.pl
 This is part of PgXexplorer software, Open Source
 on BSD licence, Libraries(interaces) used:
 GNU GCC, AS (all stuff needed to compile C source into executable binary)
 LibPQ-FE from PostgreSQL, GTK (GIMP Toolkit)
 written in VIM editor, ctags used, CVS used
 Currently only one author: MOrgoth DBMA
 FILE: signals.c */
#include "signals.h"

extern int ping_conn;

void priv_sig_proc()
{
 debug("%s:%d", __FILE__,__LINE__);
 ping_conn=0;
 gtk_dialog_printf("Tiomeout!\nConnection lost!\nSystem will now exit");
 exit(1);
 ping_conn=0;
 
}


void alarm_clock(int sec)
{
 debug("%s:%d", __FILE__,__LINE__);
 alarm(sec);
}


void alarm_stop()
{
 debug("%s:%d", __FILE__,__LINE__);
 alarm(0);
}


void setup_signals()
{
 static struct sigaction act;
 ping_conn=0;
 debug("%s:%d", __FILE__,__LINE__);
 act.sa_handler = priv_sig_proc;
 sigfillset(&(act.sa_mask));
 sigfillset(&(act.sa_mask));
 sigaction(SIGALRM, &act, NULL);
}

